@@ -1,8 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 2002,2006 Rami Lehti, Pablo Virolainen, Richard van den
- * Berg
- * $Header$
+ * Copyright (C) 2002, 2006, 2019-2020 Rami Lehti, Pablo Virolainen,
+ *               Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,22 +14,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _URL_H_INCLUDED
 #define _URL_H_INCLUDED
 
 typedef enum {
-  url_file, url_stdout, url_stdin, url_stderr, url_fd, url_http,
-  url_sql, url_syslog, url_database, url_multiwriter, 
-  url_gzip, url_string, url_ftp, url_https, 
-  url_unknown
+  url_file = 1,
+  url_stdout,
+  url_stdin,
+  url_stderr,
+  url_fd,
+  url_ftp,
+  url_http,
+  url_https,
+  url_syslog,
 } URL_TYPE;
 
-
 typedef struct url_t {
   /* Everything before the first ':' */
   URL_TYPE type;
@@ -37,6 +41,8 @@ typedef struct url_t {
   void* data; /* We might want to pass some list's to multiwriter */ 
 } url_t;
 
+URL_TYPE get_url_type(char *);
 
+const char* get_url_type_string(URL_TYPE);
 
 #endif
