@@ -1,8 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002,2006 Rami Lehti, Pablo Virolainen, Richard
- * van den Berg
- * $Header$
+ * Copyright (C) 1999-2002, 2006, 2013, 2020-2022 Rami Lehti, Pablo Virolainen,
+ *               Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,16 +14,19 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _UTIL_H_INCLUDED
 #define _UTIL_H_INCLUDED
+#include "config.h"
 #include <string.h>
+#include <stdbool.h>
+#include <inttypes.h>
 #include <sys/types.h>
-#include "db_config.h"
+#include "url.h"
 
 #define HEXD2ASC(x) (((x) < 10) ? ((x) + '0') : ((x) - 10 + 'A'))
 
@@ -38,9 +41,19 @@
 #  define stricmp(a,b)   strcasecmp( (a), (b) )
 #endif
 
-int cmpurl(url_t*, url_t*);
+#ifndef HAVE_BYTE
+typedef uint8_t byte;
+#endif
 
-url_t* parse_url(char*);
+const char* btoa(bool);
+
+void* checked_malloc(size_t);
+void* checked_calloc(size_t, size_t);
+void* checked_strdup(const char *);
+void* checked_strndup(const char *, size_t);
+void* checked_realloc(void *, size_t);
+
+int cmpurl(url_t*, url_t*);
 
 int contains_unsafe(const char*);
 
@@ -50,9 +63,9 @@ char* encode_string(const char*);
 
 char* perm_to_char(mode_t perm);
 
-void sig_handler(int signal);
+char *expand_tilde(char * path);
 
-void init_sighandler(void);
+char* pipe2string(int);
 
 #ifndef HAVE_STRNSTR
 char* strnstr(char* haystack,char* needle,int n);
@@ -62,6 +75,8 @@ char* strnstr(char* haystack,char* needle,int n);
 size_t strnlen(const char *s, size_t maxlen);
 #endif
 
+#ifdef HAVE_SYSLOG
 int syslog_facility_lookup(char *);
+#endif
 
 #endif
