@@ -1,7 +1,7 @@
 /*
  * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2003, 2005-2006, 2010-2011, 2013, 2019-2021 Rami Lehti,
+ * Copyright (C) 1999-2003, 2005-2006, 2010-2011, 2013, 2019-2023 Rami Lehti,
  *               Pablo Virolainen, Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
@@ -19,14 +19,19 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "aide.h"
+#include "config.h"
 #include <string.h>
 #include <stdio.h>
+#include <stdbool.h>
 #include <stdlib.h>
-#include <stdarg.h>
+#ifdef HAVE_FCNTL
+#include <fcntl.h>
+#endif
 #include <unistd.h>
 #include <errno.h>
-#include "db_file.h"
+#ifdef WITH_ZLIB
+#include <zlib.h>
+#endif
 #include "log.h"
 #include "util.h"
 #include "errorcodes.h"
@@ -34,6 +39,7 @@
 #include "fopen.h"
 #endif
 #include "be.h"
+#include "url.h"
 
 /*for locale support*/
 #include "locale-aide.h"
@@ -52,14 +58,14 @@ void* be_init(bool readonly, url_t* u, bool iszipped, bool append, int linenumbe
   switch (u->type) {
   case url_file : {
     u->value = expand_tilde(u->value);
-    log_msg(LOG_LEVEL_DEBUG, "open (%s, gzip: %s, append: %s ) file '%s'", readonly?"read-only":"read/write", btoa(iszipped), btoa(append), u->value);
+    log_msg(LOG_LEVEL_DEBUG, "open (%s, gzip: %s, append: %s) file '%s'", readonly?"read-only":"read/write", btoa(iszipped), btoa(append), u->value);
 #if HAVE_FCNTL && HAVE_FTRUNCATE
     fd=open(u->value,readonly?O_RDONLY:O_CREAT|O_RDWR|(append?O_APPEND:0),0666);
 #else
     fd=open(u->value,readonly?O_RDONLY:O_CREAT|O_RDWR|(append?O_APPEND:O_TRUNC),0666);
 #endif
     if(fd==-1) {
-        LOG_CONFIG_FORMAT_LINE(LOG_LEVEL_ERROR, open (%s) failed for file '%s': %s, readonly?"read-only":"read/write", u->value, strerror(errno));
+        LOG_CONFIG_FORMAT_LINE(LOG_LEVEL_ERROR, "open (%s) failed for file '%s': %s", readonly?"read-only":"read/write", u->value, strerror(errno));
       return NULL;
     } else {
         log_msg(LOG_LEVEL_DEBUG, "opened file '%s' with fd=%i",u->value,fd);
